@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Crypt
  */
@@ -19,7 +19,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Crypt
  * @since     2.4.0
@@ -58,7 +58,7 @@ class Horde_Crypt_Pgp_Keyserver
      *   - port: (integer) The public PGP keyserver port.
      * </pre>
      */
-    public function __construct(Horde_Crypt_Pgp $pgp, array $params = array())
+    public function __construct($pgp, array $params = array())
     {
         $this->_pgp = $pgp;
         $this->_http = (isset($params['http']) && ($params['http'] instanceof Horde_Http_Client))
