@@ -2,7 +2,7 @@
 /**
  * Library to interact with the OpenSSL library and implement S/MIME.
  *
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -15,6 +15,17 @@
  */
 class Horde_Crypt_Smime extends Horde_Crypt
 {
+    /**
+     * Constructor.
+     *
+     * @param array $params  Configuration parameters:
+     *   - temp: (string) Location of temporary directory.
+     */
+    public function __construct($params = array())
+    {
+        parent::__construct($params);
+    }
+
     /**
      * Verify a passphrase for a given private key.
      *
@@ -195,19 +206,35 @@ class Horde_Crypt_Smime extends Horde_Crypt
     public function signMIMEPart($mime_part, $params)
     {
         /* Sign the part as a message */
-        $message = $this->encrypt($mime_part->toString(array('headers' => true, 'canonical' => true)), $params);
+        $message = $this->encrypt(
+            $mime_part->toString(array(
+                'headers' => true,
+                'canonical' => true
+            )),
+            $params
+        );
 
         /* Break the result into its components */
-        $mime_message = Horde_Mime_Part::parseMessage($message, array('forcemime' => true));
+        $mime_message = Horde_Mime_Part::parseMessage(
+            $message,
+            array('forcemime' => true)
+        );
 
         $smime_sign = $mime_message->getPart('2');
-        $smime_sign->setDescription(Horde_Crypt_Translation::t("S/MIME Signature"));
+        $smime_sign->setDescription(
+            Horde_Crypt_Translation::t("S/MIME Signature")
+        );
         $smime_sign->setTransferEncoding('base64', array('send' => true));
 
         $smime_part = new Horde_Mime_Part();
         $smime_part->setType('multipart/signed');
-        $smime_part->setContents("This is a cryptographically signed message in MIME format.\n");
-        $smime_part->setContentTypeParameter('protocol', 'application/pkcs7-signature');
+        $smime_part->setContents(
+            "This is a cryptographically signed message in MIME format.\n"
+        );
+        $smime_part->setContentTypeParameter(
+            'protocol',
+            'application/pkcs7-signature'
+        );
         // Per RFC 5751 [3.4.3.2], 'sha1' has been deprecated for 'sha-1'.
         $smime_part->setContentTypeParameter('micalg', 'sha-1');
         $smime_part->addPart($mime_part);
@@ -230,16 +257,27 @@ class Horde_Crypt_Smime extends Horde_Crypt
     public function encryptMIMEPart($mime_part, $params = array())
     {
         /* Sign the part as a message */
-        $message = $this->encrypt($mime_part->toString(array('headers' => true, 'canonical' => true)), $params);
+        $message = $this->encrypt(
+            $mime_part->toString(array(
+                'headers' => true,
+                'canonical' => true
+            )),
+            $params
+        );
 
         $msg = new Horde_Mime_Part();
         $msg->setCharset($this->_params['email_charset']);
         $msg->setHeaderCharset('UTF-8');
-        $msg->setDescription(Horde_Crypt_Translation::t("S/MIME Encrypted Message"));
+        $msg->setDescription(
+            Horde_Crypt_Translation::t("S/MIME Encrypted Message")
+        );
         $msg->setDisposition('inline');
         $msg->setType('application/pkcs7-mime');
         $msg->setContentTypeParameter('smime-type', 'enveloped-data');
-        $msg->setContents(substr($message, strpos($message, "\n\n") + 2), array('encoding' => 'base64'));
+        $msg->setContents(
+            substr($message, strpos($message, "\n\n") + 2),
+            array('encoding' => 'base64')
+        );
 
         return $msg;
     }
@@ -249,12 +287,9 @@ class Horde_Crypt_Smime extends Horde_Crypt
      *
      * @param string $text   The text to be encrypted.
      * @param array $params  The parameters needed for encryption.
-     * <pre>
-     * Parameters:
-     * ===========
-     * 'type'   => 'message' (REQUIRED)
-     * 'pubkey' => public key (REQUIRED)
-     * </pre>
+     *   - type: (string) [REQUIRED] 'message'.
+     *   - pubkey: (mixed) [REQUIRED] Public key/cert or array of public
+     *             keys/certs.
      *
      * @return string  The encrypted message.
      * @throws Horde_Crypt_Exception
@@ -263,7 +298,9 @@ class Horde_Crypt_Smime extends Horde_Crypt
     {
         /* Check for required parameters. */
         if (!isset($params['pubkey'])) {
-            throw new Horde_Crypt_Exception(Horde_Crypt_Translation::t("A public S/MIME key is required to encrypt a message."));
+            throw new Horde_Crypt_Exception(Horde_Crypt_Translation::t(
+                "A public S/MIME key is required to encrypt a message."
+            ));
         }
 
         /* Create temp files for input/output. */
@@ -276,23 +313,35 @@ class Horde_Crypt_Smime extends Horde_Crypt
 
         /* Encrypt the document. */
         $ciphers = array(
-            OPENSSL_CIPHER_3DES,
-            OPENSSL_CIPHER_DES,
-            OPENSSL_CIPHER_RC2_128,
-            OPENSSL_CIPHER_RC2_64,
-            OPENSSL_CIPHER_RC2_40
+            // SHOULD- support (RFC 5751 [2.7])
+            OPENSSL_CIPHER_3DES
         );
+        if (defined('OPENSSL_CIPHER_AES_128_CBC')) {
+            // MUST support (RFC 5751 [2.7])
+            array_unshift($ciphers, OPENSSL_CIPHER_AES_128_CBC);
+            // SHOULD+ support (RFC 5751 [2.7])
+            array_unshift($ciphers, OPENSSL_CIPHER_AES_192_CBC);
+            array_unshift($ciphers, OPENSSL_CIPHER_AES_256_CBC);
+        }
 
         foreach ($ciphers as $val) {
-            if (openssl_pkcs7_encrypt($input, $output, $params['pubkey'], array(), 0, $val)) {
-                $result = file_get_contents($output);
-                if (!empty($result)) {
-                    return $this->_fixContentType($result, 'encrypt');
-                }
+            $success = openssl_pkcs7_encrypt(
+                $input,
+                $output,
+                $params['pubkey'],
+                array(),
+                0,
+                $val
+            );
+
+            if ($success && ($result = file_get_contents($output))) {
+                return $this->_fixContentType($result, 'message');
             }
         }
 
-        throw new Horde_Crypt_Exception(Horde_Crypt_Translation::t("Could not S/MIME encrypt message."));
+        throw new Horde_Crypt_Exception(Horde_Crypt_Translation::t(
+            "Could not S/MIME encrypt message."
+        ));
     }
 
     /**
@@ -780,4 +829,18 @@ class Horde_Crypt_Smime extends Horde_Crypt
         return str_replace('Content-Type: ' . $from, 'Content-Type: ' . $to, $text);
     }
 
+    /**
+     * Create a temporary file that will be deleted at the end of this
+     * process.
+     *
+     * @param string $descrip  Description string to use in filename.
+     * @param boolean $delete  Delete the file automatically?
+     *
+     * @return string Filename of a temporary file.
+     */
+    protected function _createTempFile($descrip = 'horde-crypt', $delete = true)
+    {
+        return Horde_Util::getTempFile($descrip, $delete, $this->_params['temp'], true);
+    }
+
 }
